pub fn spawn_sprite_components(
commands: Commands<'_, '_>,
asset_server: Res<'_, AssetServer>,
sprite_data_assets: ResMut<'_, Assets<SpriteData>>,
query: Query<'_, '_, (Entity, &EntityProperties), Without<SpriteSlot>>,
)Expand description
System that detects entities with sprite properties and adds Sprite + AnimatedSprite components
This follows the Bevy pattern of adding sprite components directly to the entity
rather than spawning child entities. This makes animation control much simpler
as games can query AnimatedSprite directly on their entity types.